// WWManager.h
// By Alex B. Cone, Objective Technologies, Inc
// Copyright (c) 1991, Objective Technologies, Inc.

#import <appkit/appkit.h>
#import "WWManager.h"
#import "NiftyMatrix.h"
#import <otikit/OTChooser.h>
#import <pwd.h>

@implementation WWManager

+ initialize
{
/*	This class is a subclass of Application so that we can set the
	Chooser's matrix class before the main nib file is read in.  This
	is also the reason that the Chooser is loaded as a custom view - 
	custom views receive init methods, while objects dragged from the
	palette are de-archived with reads.  A Chooser dragged from the 
	palette will be archived with the Matrix class as its matrix -
	this is the default.  The NiftyMatrix class is taken from the
	ScrollDudeScroll example in /NextDeveloper/Examples.
	
	After this message is sent to the OTChooser factory, all subsequent
	instances of OTChooser will be created with the NiftyMatrix (unless
	another matrix class is specified by the use of the
	initFrame:titles:matrixClass:prototype: method.)
*/

	[OTChooser setMatrixClass:[NiftyMatrix class]];
	return [super initialize];
}

+ new
{
	self = [super new];
	
/*	Load the shared images for use in the OTChooserCell's icon.  The
	Chooser will display faster if you use shared images - in almost
	all cases, you are using a small list of icons.  The OTChooser
	will also consume less memory if it is not keeping a seperate icon
	for each cell.
*/

	unknownImage = [[NXImage alloc] initFromSection:"unknown"];
	femaleImage = [[NXImage alloc] initFromSection:"female"];
	machineImage = [[NXImage alloc] initFromSection:"machine"];
	maleImage = [[NXImage alloc] initFromSection:"male"];
    return self;
}

- appDidInit:sender
{
/*	The nib file has been loaded now.  We need to set up the Chooser since
	we didn't drag it off the palette.
*/

	[chooser setUnselectVisible:YES];
	[chooser setIconVisible:YES];
	[chooser setTagVisible:YES];
	[chooser setTitle:"System Users"];
	return self;
}

- loadChooser:sender
{
	char buffer[128];
	struct passwd *entry;
	id	aCell, theWindow = [chooser window];

/*	This is an example of how to turn the Chooser's display off while
	we load all the cells.  If you are loading a lot of cells at once,
	this will speed up the load.
*/

	[theWindow disableFlushWindow];
	[[[chooser titleView] docView] setAutodisplay:NO];

/* clear the Chooser - icon images are not freed with the OTChooserCells */
	[chooser clear];
	setpwent();
	
	while (entry = getpwent()) {
		aCell = [[chooser prototype] copy];
		[aCell setIconImage:unknownImage];
		[aCell setTag:entry->pw_uid];
		sprintf(buffer,"%s - %s",entry->pw_name,entry->pw_gecos);
		[aCell setStringValue:buffer];
		[chooser addCellAtEnd:aCell];
	}

/*	Turn the display back on... */
	[[[chooser titleView] docView] setAutodisplay:YES];
	[chooser display];
	[theWindow reenableFlushWindow];
	[theWindow flushWindow];
    return self;
}

- updateChooser:sender
{
	id	aCell = [chooser selectedCell];
	
	[aCell setStringValue:[nameField stringValue]];
	if ([typeMatrix selectedCol] == 0) [aCell setIconImage:maleImage];
	if ([typeMatrix selectedCol] == 1) [aCell setIconImage:femaleImage];
	if ([typeMatrix selectedCol] == 2) [aCell setIconImage:machineImage];
	[chooser display];
    return self;
}

@end
